@@ -1,20 +1,23 @@
 # -*- coding: utf-8 -*-
+import os
 import logging
+import warnings
 
 from django.conf import settings
 from django.core.management.base import BaseCommand, CommandError
+from django.db import DEFAULT_DB_ALIAS
 from django.db.backends.base.creation import TEST_DATABASE_PREFIX
-from six.moves import input
 
 from django_extensions.management.mysql import parse_mysql_cnf
 from django_extensions.management.utils import signalcommand
+from django_extensions.utils.deprecation import RemovedInNextVersionWarning
 
 
 class Command(BaseCommand):
     help = "Drops test database for this project."
 
     def add_arguments(self, parser):
-        super(Command, self).add_arguments(parser)
+        super().add_arguments(parser)
         parser.add_argument(
             '--noinput', action='store_false', dest='interactive',
             default=True, help='Tells Django to NOT prompt the user for input of any kind.'
@@ -32,19 +35,25 @@ class Command(BaseCommand):
             help='Use another database name then defined in settings.py'
         )
         parser.add_argument(
-            '-R', '--router', action='store', dest='router', default='default',
+            '-R', '--router', action='store', dest='router', default=DEFAULT_DB_ALIAS,
             help='Use this router-database other then defined in settings.py'
         )
+        parser.add_argument(
+            '--database', default=DEFAULT_DB_ALIAS,
+            help='Nominates a database to run command for. Defaults to the "%s" database.' % DEFAULT_DB_ALIAS,
+        )
 
     @signalcommand
     def handle(self, *args, **options):
-        """
-        Drop test database for this project.
-        """
-        router = options['router']
-        dbinfo = settings.DATABASES.get(router)
+        """Drop test database for this project."""
+        database = options['database']
+        if options['router'] != DEFAULT_DB_ALIAS:
+            warnings.warn("--router is deprecated. You should use --database.", RemovedInNextVersionWarning, stacklevel=2)
+            database = options['router']
+
+        dbinfo = settings.DATABASES.get(database)
         if dbinfo is None:
-            raise CommandError("Unknown database router %s" % router)
+            raise CommandError("Unknown database %s" % database)
 
         engine = dbinfo.get('ENGINE').split('.')[-1]
 
@@ -86,7 +95,6 @@ Type 'yes' to continue, or 'no' to cancel: """ % (database_name,))
             return
 
         if engine in ('sqlite3', 'spatialite'):
-            import os
             try:
                 logging.info("Unlinking %s database" % engine)
                 if os.path.isfile(database_name):
