@@ -6,21 +6,23 @@ originally from http://www.djangosnippets.org/snippets/828/ by dnordberg
 """
 import os
 import logging
+import warnings
 
 from django.conf import settings
 from django.core.management.base import BaseCommand, CommandError
-from six.moves import input
+from django.db import DEFAULT_DB_ALIAS
 
 from django_extensions.settings import SQLITE_ENGINES, POSTGRESQL_ENGINES, MYSQL_ENGINES
 from django_extensions.management.mysql import parse_mysql_cnf
 from django_extensions.management.utils import signalcommand
+from django_extensions.utils.deprecation import RemovedInNextVersionWarning
 
 
 class Command(BaseCommand):
     help = "Resets the database for this project."
 
     def add_arguments(self, parser):
-        super(Command, self).add_arguments(parser)
+        super().add_arguments(parser)
         parser.add_argument(
             '--noinput', action='store_false',
             dest='interactive', default=True,
@@ -48,9 +50,13 @@ class Command(BaseCommand):
             help='Use another database name than defined in settings.py'
         )
         parser.add_argument(
-            '-R', '--router', action='store', dest='router', default='default',
+            '-R', '--router', action='store', dest='router', default=DEFAULT_DB_ALIAS,
             help='Use this router-database other than defined in settings.py'
         )
+        parser.add_argument(
+            '--database', default=DEFAULT_DB_ALIAS,
+            help='Nominates a database to run command for. Defaults to the "%s" database.' % DEFAULT_DB_ALIAS,
+        )
         parser.add_argument(
             '-c', '--close-sessions', action='store_true', dest='close_sessions', default=False,
             help='Close database connections before dropping database (PostgreSQL only)'
@@ -64,10 +70,14 @@ class Command(BaseCommand):
         Note: Transaction wrappers are in reverse as a work around for
         autocommit, anybody know how to do this the right way?
         """
-        router = options['router']
-        dbinfo = settings.DATABASES.get(router)
+        database = options['database']
+        if options['router'] != DEFAULT_DB_ALIAS:
+            warnings.warn("--router is deprecated. You should use --database.", RemovedInNextVersionWarning, stacklevel=2)
+            database = options['router']
+
+        dbinfo = settings.DATABASES.get(database)
         if dbinfo is None:
-            raise CommandError("Unknown database router %s" % router)
+            raise CommandError("Unknown database %s" % database)
 
         engine = dbinfo.get('ENGINE')
 
