@@ -1,29 +1,36 @@
 # -*- coding: utf-8 -*-
 import socket
 import sys
+import warnings
 
 from django.conf import settings
 from django.core.management.base import BaseCommand, CommandError
+from django.db import DEFAULT_DB_ALIAS
 
 from django_extensions.management.utils import signalcommand
+from django_extensions.utils.deprecation import RemovedInNextVersionWarning
 
 
 class Command(BaseCommand):
     help = """Generates the SQL to create your database for you, as specified in settings.py
 The envisioned use case is something like this:
 
-    ./manage.py sqlcreate [--router=<routername>] | mysql -u <db_administrator> -p
-    ./manage.py sqlcreate [--router=<routername>] | psql -U <db_administrator> -W"""
+    ./manage.py sqlcreate [--database=<databasename>] | mysql -u <db_administrator> -p
+    ./manage.py sqlcreate [--database=<databasname>] | psql -U <db_administrator> -W"""
 
     requires_system_checks = False
     can_import_settings = True
 
     def add_arguments(self, parser):
-        super(Command, self).add_arguments(parser)
+        super().add_arguments(parser)
         parser.add_argument(
-            '-R', '--router', action='store', dest='router', default='default',
+            '-R', '--router', action='store', dest='router', default=DEFAULT_DB_ALIAS,
             help='Use this router-database other then defined in settings.py'
         )
+        parser.add_argument(
+            '--database', default=DEFAULT_DB_ALIAS,
+            help='Nominates a database to run command for. Defaults to the "%s" database.' % DEFAULT_DB_ALIAS,
+        )
         parser.add_argument(
             '-D', '--drop', action='store_true', dest='drop', default=False,
             help='If given, includes commands to drop any existing user and database.'
@@ -31,10 +38,14 @@ The envisioned use case is something like this:
 
     @signalcommand
     def handle(self, *args, **options):
-        router = options['router']
-        dbinfo = settings.DATABASES.get(router)
+        database = options['database']
+        if options['router'] != DEFAULT_DB_ALIAS:
+            warnings.warn("--router is deprecated. You should use --database.", RemovedInNextVersionWarning, stacklevel=2)
+            database = options['router']
+
+        dbinfo = settings.DATABASES.get(database)
         if dbinfo is None:
-            raise CommandError("Unknown database router %s" % router)
+            raise CommandError("Unknown database %s" % database)
 
         engine = dbinfo.get('ENGINE').split('.')[-1]
         dbuser = dbinfo.get('USER')
@@ -56,7 +67,6 @@ The envisioned use case is something like this:
             print("GRANT ALL PRIVILEGES ON %s.* to '%s'@'%s' identified by '%s';" % (
                 dbname, dbuser, dbclient, dbpass
             ))
-
         elif engine in ('postgresql', 'postgresql_psycopg2', 'postgis'):
             if options['drop']:
                 print("DROP DATABASE IF EXISTS %s;" % (dbname,))
@@ -65,10 +75,8 @@ The envisioned use case is something like this:
             print("CREATE USER %s WITH ENCRYPTED PASSWORD '%s' CREATEDB;" % (dbuser, dbpass))
             print("CREATE DATABASE %s WITH ENCODING 'UTF-8' OWNER \"%s\";" % (dbname, dbuser))
             print("GRANT ALL PRIVILEGES ON DATABASE %s TO %s;" % (dbname, dbuser))
-
         elif engine == 'sqlite3':
             sys.stderr.write("-- manage.py syncdb will automatically create a sqlite3 database file.\n")
-
         else:
             # CREATE DATABASE is not SQL standard, but seems to be supported by most.
             sys.stderr.write("-- Don't know how to handle '%s' falling back to SQL.\n" % engine)
